
Core Modules
============

The modules forming the core of astropysics' functionality are documented below.
These are primarily useful in a script or interpreter setting, and hence are
non-GUI. All plotting functions in these modules use `matplotlib
<http://matplotlib.sourceforge.net/index.html>`_, allowing them to be used in
`ipython <http://ipython.scipy.org>`_ without blocking the interactive
interpreter.

.. toctree::
   :maxdepth: 2
   
   
   constants
   coords
   models
   objcat
   ccd
   spec
   phot
   obstools
   plotting
   pipeline
   publication
   utils
   config
